pub struct Gpio1<'a>(/* private fields */);Implementations
Sourceimpl Gpio1<'_>
impl Gpio1<'_>
Sourcepub unsafe fn steal() -> Gpio1<'_>
pub unsafe fn steal() -> Gpio1<'_>
Unsafely create an instance of this peripheral out of thin air.
Safety
You must ensure that you’re only using one instance of this type at a time.
Sourcepub unsafe fn reborrow(&mut self) -> Gpio1<'_>
pub unsafe fn reborrow(&mut self) -> Gpio1<'_>
Creates a new peripheral reference with a shorter lifetime.
Use this method if you would like to keep working with the peripheral after you dropped the driver that consumes this.
Safety
You must ensure that you are not using reborrowed peripherals in drivers which are
forgotten via core::mem::forget.
Sourceimpl<'a> Gpio1<'a>
impl<'a> Gpio1<'a>
pub fn degrade_input(self) -> AnyInputPin<'a>
Sourceimpl<'a> Gpio1<'a>
impl<'a> Gpio1<'a>
pub fn degrade_output(self) -> AnyOutputPin<'a>
pub fn degrade_input_output(self) -> AnyIOPin<'a>